@@ -11,10 +11,8 @@ def v2_only():
     return not include_v1()
 
 
-def shorten_str(text, to_chars=100):
-    if "\n" in text or len(text) > 50:
-        return None
-    return text
+def unshowable_string(text):
+    return "\n" in text or len(text) > 50
 
 
 def copy_env(env):
